import React, { PropsWithChildren, MouseEventHandler, FC } from 'react';
import { AvatarClasses, AvatarPropsVariantOverrides } from '@mui/material/Avatar';
import { SxProps, Theme, AvatarGroupClasses, Avatar as Avatar$1, AvatarGroupComponentsPropsOverrides, BadgeOrigin, BadgeClasses, BadgePropsColorOverrides, BadgeOwnProps, BadgeRootSlotPropsOverrides, BadgeOwnerState, BadgeBadgeSlotPropsOverrides, BadgePropsVariantOverrides, PopoverProps, MenuClasses, MenuListProps as MenuListProps$1, PopoverOrigin, MenuItemClasses, ListItemClasses, ListItemIconClasses, ListItemAvatarClasses, ListItemButtonClasses, ListItemTextClasses, TooltipClasses, PopperProps, TooltipComponentsPropsOverrides, TableRowClasses, TableSortLabelClasses, SelectProps, GridClasses, GridSpacing, GridDirection, GridWrap, GridSize, ModalProps, PaperProps as PaperProps$1, SlideProps as SlideProps$1, TabScrollButtonProps, StepIconProps, TypographyOwnProps, PropTypes, IconButtonProps, SvgIconProps, Breakpoint, ClassNameMap, TypographyProps } from '@mui/material';
import { OverridableStringUnion } from '@mui/types';
import { SlotComponentProps } from '@mui/base';
import { TransitionProps } from '@mui/material/transitions';
import { ListClasses } from '@mui/material/List';
import { DividerClasses } from '@mui/material/Divider';
import { MUIStyledCommonProps, ResponsiveStyleValue, SxProps as SxProps$1, Theme as Theme$1 } from '@mui/system';
import { TableClasses } from '@mui/material/Table';
import { TableBodyClasses } from '@mui/material/TableBody';
import { TableCellClasses, TableCellBaseProps, SortDirection } from '@mui/material/TableCell';
import { TableContainerClasses } from '@mui/material/TableContainer';
import { TableFooterClasses } from '@mui/material/TableFooter';
import { TableHeadClasses } from '@mui/material/TableHead';
import { TablePaginationClasses, LabelDisplayedRowsArgs } from '@mui/material/TablePagination';
import { TablePaginationActionsProps } from '@mui/material/TablePagination/TablePaginationActions';
import { DrawerClasses } from '@mui/material/Drawer';
import { StepperClasses, Orientation } from '@mui/material/Stepper';
import { TabsActions, TabsClasses } from '@mui/material/Tabs';
import { TabClasses } from '@mui/material/Tab';
import { StepClasses } from '@mui/material/Step';
import { StepButtonClasses } from '@mui/material/StepButton';
import { StepLabelClasses } from '@mui/material/StepLabel';
import { StepContentClasses } from '@mui/material/StepContent';
import { TypographyClasses, TypographyPropsVariantOverrides } from '@mui/material/Typography';
import { Variant } from '@mui/material/styles/createTypography';
import { AccordionClasses, AccordionSlots as AccordionSlots$1, AccordionTransitionSlotPropsOverrides, AccordionOwnerState } from '@mui/material/Accordion';
import { SlotProps } from '@mui/material/utils/types';
import { AccordionDetailsClasses } from '@mui/material/AccordionDetails';
import { AccordionSummaryClasses } from '@mui/material/AccordionSummary';
import { CardClasses } from '@mui/material/Card';
import { CardActionsClasses } from '@mui/material/CardActions';
import { CardContentClasses } from '@mui/material/CardContent';
import { LinkClasses } from '@mui/material/Link';
import { AppBarClasses, AppBarPropsColorOverrides } from '@mui/material/AppBar';
import { AlertClasses, AlertColor, AlertPropsColorOverrides, AlertPropsVariantOverrides } from '@mui/material/Alert';
import { AlertTitleClasses } from '@mui/material/AlertTitle';
import { BackdropComponentsPropsOverrides, BackdropClasses } from '@mui/material/Backdrop';
import { DialogClasses } from '@mui/material/Dialog';
import { DialogActionsClasses } from '@mui/material/DialogActions';
import { DialogContentClasses } from '@mui/material/DialogContent';
import { DialogContentTextClasses } from '@mui/material/DialogContentText';
import { DialogTitleClasses } from '@mui/material/DialogTitle';
import { ChipClasses, ChipPropsColorOverrides, ChipPropsSizeOverrides, ChipPropsVariantOverrides } from '@mui/material/Chip';
import { ToolbarClasses, ToolbarPropsVariantOverrides } from '@mui/material/Toolbar';
import { PaperClasses, PaperPropsVariantOverrides } from '@mui/material/Paper';
import { FormGroupClasses } from '@mui/material/FormGroup';
import { FormControlClasses, FormControlPropsColorOverrides, FormControlPropsSizeOverrides } from '@mui/material/FormControl';
import { FormControlLabelClasses } from '@mui/material/FormControlLabel';
import { FormHelperTextClasses, FormHelperTextPropsVariantOverrides } from '@mui/material/FormHelperText';
import { FormLabelClasses, FormLabelPropsColorOverrides } from '@mui/material/FormLabel';
import { CircularProgressClasses, CircularProgressPropsColorOverrides } from '@mui/material/CircularProgress';
import { LinearProgressClasses, LinearProgressPropsColorOverrides } from '@mui/material/LinearProgress';
import * as Icons from '@mui/icons-material';

type ButtonProps = PropsWithChildren & {
    key: string;
    label: string;
    color: string;
    disabled: boolean;
    disableElevation: boolean;
    size: "small" | "medium" | "large";
    varient: "text" | "contained" | "outlined";
    icon: React.ReactElement;
    iconPosition: "start" | "end";
};
declare const Button: (props: ButtonProps) => React.JSX.Element;

type ButtonGroupProps = PropsWithChildren & {
    key: string;
    label: string;
    icon: React.ReactElement;
};
declare const ButtonGroup: (props: ButtonGroupProps) => React.JSX.Element;

type CheckboxProps = PropsWithChildren & {
    key: string;
    label: string;
    icon: React.ReactElement;
};
declare const Checkbox: (props: CheckboxProps) => React.JSX.Element;

type AvatarProps = PropsWithChildren & {
    key?: string;
    /**
    * Used in combination with `src` or `srcSet` to
    * provide an alt attribute for the rendered `img` element.
    */
    alt?: string;
    /**
     * Used to render icon or text elements inside the Avatar if `src` is not set.
     * This can be an element, or just a string.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AvatarClasses>;
    /**
     * [Attributes](https://developer.mozilla.org/en-US/docs/Web/HTML/Element/img#attributes) applied to the `img` element if the component is used to display an image.
     * It can be used to listen for the loading error event.
     * @deprecated Use `slotProps.img` instead. This prop will be removed in v7. [How to migrate](/material-ui/migration/migrating-from-deprecated-apis/).
     */
    imgProps?: React.ImgHTMLAttributes<HTMLImageElement> & {
        sx?: SxProps<Theme>;
    };
    /**
     * The `sizes` attribute for the `img` element.
     */
    sizes?: string;
    /**
     * The `src` attribute for the `img` element.
     */
    src?: string;
    /**
     * The `srcSet` attribute for the `img` element.
     * Use this attribute for responsive image display.
     */
    srcSet?: string;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The shape of the avatar.
     * @default 'circular'
     */
    variant?: OverridableStringUnion<'circular' | 'rounded' | 'square', AvatarPropsVariantOverrides>;
};
declare const Avatar: (props: AvatarProps) => React.JSX.Element;

type AvatarGroupProps = PropsWithChildren & {
    key?: string;
    /**
  * The avatars to stack.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AvatarGroupClasses>;
    /**
     * The component used for the root node.
     * Either a string to use a HTML element or a component.
     */
    component?: React.ElementType;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `slotProps` prop.
     * It's recommended to use the `slotProps` prop instead, as `componentsProps` will be deprecated in the future.
     *
     * @default {}
     */
    componentsProps?: {
        additionalAvatar?: React.ComponentPropsWithRef<typeof Avatar$1> & AvatarGroupComponentsPropsOverrides;
    };
    /**
     * Max avatars to show before +x.
     * @default 5
     */
    max?: number;
    /**
     * custom renderer of extraAvatars
     * @param {number} surplus number of extra avatars
     * @returns {React.ReactNode} custom element to display
     */
    renderSurplus?: (surplus: number) => React.ReactNode;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `componentsProps` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slotProps?: {
        additionalAvatar?: React.ComponentPropsWithRef<typeof Avatar$1> & AvatarGroupComponentsPropsOverrides;
    };
    /**
     * Spacing between avatars.
     * @default 'medium'
     */
    spacing?: 'small' | 'medium' | number;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The total number of avatars. Used for calculating the number of extra avatars.
     * @default children.length
     */
    total?: number;
    /**
     * The variant to use.
     * @default 'circular'
     */
    variant?: 'circular' | 'rounded' | 'square';
};
declare const AvatarGroup: (props: AvatarGroupProps) => React.JSX.Element;

type BadgeProps = PropsWithChildren & {
    key?: string;
    /**
    * The anchor of the badge.
    * @default {
    *   vertical: 'top',
    *   horizontal: 'right',
    * }
    */
    anchorOrigin?: BadgeOrigin;
    /**
     * The content rendered within the badge.
     */
    badgeContent?: React.ReactNode;
    /**
     * The badge will be added relative to this node.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<BadgeClasses>;
    /**
     * @ignore
     */
    className?: string;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'default'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'default' | 'error' | 'info' | 'success' | 'warning', BadgePropsColorOverrides>;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `slotProps` prop.
     * It's recommended to use the `slotProps` prop instead, as `componentsProps` will be deprecated in the future.
     *
     * @default {}
     */
    componentsProps?: BadgeOwnProps['slotProps'];
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `slots` prop.
     * It's recommended to use the `slots` prop instead.
     *
     * @default {}
     */
    components?: {
        Root?: React.ElementType;
        Badge?: React.ElementType;
    };
    /**
     * If `true`, the badge is invisible.
     * @default false
     */
    invisible?: boolean;
    /**
     * Max count to show.
     * @default 99
     */
    max?: number;
    /**
     * Wrapped shape the badge should overlap.
     * @default 'rectangular'
     */
    overlap?: 'rectangular' | 'circular';
    /**
     * The props used for each slot inside the Badge.
     * @default {}
     */
    slotProps?: {
        root?: SlotComponentProps<'span', BadgeRootSlotPropsOverrides, BadgeOwnerState>;
        badge?: SlotComponentProps<'span', BadgeBadgeSlotPropsOverrides, BadgeOwnerState>;
    };
    /**
     * The components used for each slot inside the Badge.
     * Either a string to use a HTML element or a component.
     * @default {}
     */
    slots?: {
        /**
         * The component that renders the root.
         * @default 'span'
         */
        root?: React.ElementType;
        /**
         * The component that renders the badge.
         * @default 'span'
         */
        badge?: React.ElementType;
    };
    /**
     * Controls whether the badge is hidden when `badgeContent` is zero.
     * @default false
     */
    showZero?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The variant to use.
     * @default 'standard'
     */
    variant?: OverridableStringUnion<'standard' | 'dot', BadgePropsVariantOverrides>;
};
declare const Badge: (props: BadgeProps) => React.JSX.Element;

type MenuProps = PropsWithChildren & {
    id?: string;
    /**
   * An HTML element, or a function that returns one.
   * It's used to set the position of the menu.
   */
    anchorEl?: PopoverProps['anchorEl'];
    /**
     * If `true` (Default) will focus the `[role="menu"]` if no focusable child is found. Disabled
     * children are not focusable. If you set this prop to `false` focus will be placed
     * on the parent modal container. This has severe accessibility implications
     * and should only be considered if you manage focus otherwise.
     * @default true
     */
    autoFocus?: boolean;
    /**
     * Menu contents, normally `MenuItem`s.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<MenuClasses>;
    /**
     * When opening the menu will not focus the active item but the `[role="menu"]`
     * unless `autoFocus` is also set to `false`. Not using the default means not
     * following WAI-ARIA authoring practices. Please be considerate about possible
     * accessibility implications.
     * @default false
     */
    disableAutoFocusItem?: boolean;
    /**
     * Props applied to the [`MenuList`](/material-ui/api/menu-list/) element.
     * @default {}
     */
    MenuListProps?: Partial<MenuListProps$1>;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {object} event The event source of the callback.
     * @param {string} reason Can be: `"escapeKeyDown"`, `"backdropClick"`, `"tabKeyDown"`.
     */
    onClose?: PopoverProps['onClose'];
    /**
     * If `true`, the component is shown.
     */
    open: boolean;
    /**
     * `classes` prop applied to the [`Popover`](/material-ui/api/popover/) element.
     */
    PopoverClasses?: PopoverProps['classes'];
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The length of the transition in `ms`, or 'auto'
     * @default 'auto'
     */
    transitionDuration?: TransitionProps['timeout'] | 'auto';
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     * @default {}
     */
    TransitionProps?: TransitionProps;
    /**
     * The variant to use. Use `menu` to prevent selected items from impacting the initial focus.
     * @default 'selectedMenu'
     */
    variant?: 'menu' | 'selectedMenu';
    onClick?: MouseEventHandler<any>;
    transformOrigin?: PopoverOrigin;
    anchorOrigin?: PopoverOrigin;
    keepMounted?: boolean;
};
declare const Menu: (props: MenuProps) => React.JSX.Element;

type MenuItemProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, the list item is focused during the first mount.
    * Focus will also be triggered if the value changes from false to true.
    * @default false
    */
    autoFocus?: boolean;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<MenuItemClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent Menu component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the menu item.
     * @default false
     */
    divider?: boolean;
    /**
     * If `true`, the component is selected.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const MenuItem: (props: MenuItemProps) => React.JSX.Element;

type MenuListProps = PropsWithChildren & {
    key?: string;
    /**
  * If `true`, will focus the `[role="menu"]` container and move into tab order.
  * @default false
  */
    autoFocus?: boolean;
    /**
     * If `true`, will focus the first menuitem if `variant="menu"` or selected item
     * if `variant="selectedMenu"`.
     * @default false
     */
    autoFocusItem?: boolean;
    /**
     * MenuList contents, normally `MenuItem`s.
     */
    children?: React.ReactNode;
    /**
     * If `true`, will allow focus on disabled items.
     * @default false
     */
    disabledItemsFocusable?: boolean;
    /**
     * If `true`, the menu items will not wrap focus.
     * @default false
     */
    disableListWrap?: boolean;
    /**
     * The variant to use. Use `menu` to prevent selected items from impacting the initial focus
     * and the vertical alignment relative to the anchor element.
     * @default 'selectedMenu'
     */
    variant?: 'menu' | 'selectedMenu';
};
declare const MenuList: (props: MenuListProps) => React.JSX.Element;

type ListProps$1 = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used for
     * the list and list items.
     * The prop is available to descendant components as the `dense` context.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, vertical padding is removed from the list.
     * @default false
     */
    disablePadding?: boolean;
    /**
     * The content of the subheader, normally `ListSubheader`.
     */
    subheader?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: any;
};
declare const List: (props: ListProps$1) => React.JSX.Element;

type ListItemProps = PropsWithChildren & {
    key?: React.Key;
    /**
   * Defines the `align-items` style property.
   * @default 'center'
   */
    alignItems?: 'flex-start' | 'center';
    /**
     * If `true`, the list item is focused during the first mount.
     * Focus will also be triggered if the value changes from false to true.
     * @default false
     * @deprecated checkout [ListItemButton](/material-ui/api/list-item-button/) instead
     */
    autoFocus?: boolean;
    /**
     * The content of the component if a `ListItemSecondaryAction` is used it must
     * be the last child.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent List component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, all padding is removed.
     * @default false
     */
    disablePadding?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the list item.
     * @default false
     */
    divider?: boolean;
    /**
     * The element to display at the end of ListItem.
     */
    secondaryAction?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
   * The components used for each slot inside.
   *
   * This prop is an alias for the `slots` prop.
   * It's recommended to use the `slots` prop instead.
   *
   * @default {}
   */
    components?: {
        Root?: React.ElementType;
    };
    onClick?: MouseEventHandler<any>;
};
declare const ListItem: (props: ListItemProps) => React.JSX.Element;

type ListItemIconProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `Icon`, `SvgIcon`,
    * or a `@mui/icons-material` SVG icon element.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemIconClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const ListItemIcon: (props: ListItemIconProps) => React.JSX.Element;

type ListItemAvatarProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    sx?: SxProps<Theme>;
};
declare const ListItemAvatar: (props: ListItemAvatarProps) => React.JSX.Element;

type ListItemButtonProps = PropsWithChildren & {
    id?: string;
    /**
  * Defines the `align-items` style property.
  * @default 'center'
  */
    alignItems?: 'flex-start' | 'center';
    /**
     * If `true`, the list item is focused during the first mount.
     * Focus will also be triggered if the value changes from false to true.
     * @default false
     */
    autoFocus?: boolean;
    /**
     * The content of the component if a `ListItemSecondaryAction` is used it must
     * be the last child.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemButtonClasses>;
    /**
     * If `true`, compact vertical padding designed for keyboard and mouse input is used.
     * The prop defaults to the value inherited from the parent List component.
     * @default false
     */
    dense?: boolean;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the left and right padding is removed.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, a 1px light border is added to the bottom of the list item.
     * @default false
     */
    divider?: boolean;
    /**
     * Use to apply selected styling.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
    component?: React.ElementType;
};
declare const ListItemButton: (props: ListItemButtonProps) => React.JSX.Element;

type ListItemSecondaryActionProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    sx?: SxProps<Theme>;
};
declare const ListItemSecondaryAction: (props: ListItemSecondaryActionProps) => React.JSX.Element;

type ListItemTextProps = PropsWithChildren & {
    key?: string;
    /**
   * Alias for the `primary` prop.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemTextClasses>;
    /**
     * If `true`, the children won't be wrapped by a Typography component.
     * This can be useful to render an alternative Typography variant by wrapping
     * the `children` (or `primary`) text, and optional `secondary` text
     * with the Typography component.
     * @default false
     */
    disableTypography?: boolean;
    /**
     * If `true`, the children are indented.
     * This should be used if there is no left avatar or left icon.
     * @default false
     */
    inset?: boolean;
    /**
     * The main content element.
     */
    primary?: React.ReactNode;
    /**
     * The secondary content element.
     */
    secondary?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const ListItemText: (props: ListItemTextProps) => React.JSX.Element;

type ListSubheaderProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ListItemAvatarClasses>;
    /**
   * The color of the component. It supports those theme colors that make sense for this component.
   * @default 'default'
   */
    color?: 'default' | 'primary' | 'inherit';
    /**
     * If `true`, the List Subheader will not have gutters.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, the List Subheader will not stick to the top during scroll.
     * @default false
     */
    disableSticky?: boolean;
    /**
     * If `true`, the List Subheader is indented.
     * @default false
     */
    inset?: boolean;
    /**
  * The system prop that allows defining system overrides as well as additional CSS styles.
  */
    sx?: SxProps<Theme>;
};
declare const ListSubheader: (props: ListSubheaderProps) => React.JSX.Element;

type ListProps = PropsWithChildren & {
    key?: string;
    /**
   * Absolutely position the element.
   * @default false
   */
    absolute?: boolean;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DividerClasses>;
    /**
     * If `true`, a vertical divider will have the correct height when used in flex container.
     * (By default, a vertical divider will have a calculated height of `0px` if it is the child of a flex container.)
     * @default false
     */
    flexItem?: boolean;
    /**
     * The component orientation.
     * @default 'horizontal'
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The text alignment.
     * @default 'center'
     */
    textAlign?: 'center' | 'right' | 'left';
    /**
     * The variant to use.
     * @default 'fullWidth'
     */
    variant?: 'fullWidth' | 'inset' | 'middle';
    component?: React.ElementType;
};
declare const Divider: (props: ListProps) => React.JSX.Element;

type TooltipProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, adds an arrow to the tooltip.
    * @default false
    */
    arrow?: boolean;
    /**
     * Tooltip reference element.
     */
    children: React.ReactElement<any, any>;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TooltipClasses>;
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `slots` prop.
     * It's recommended to use the `slots` prop instead.
     *
     * @default {}
     */
    components?: {
        Popper?: React.ElementType<PopperProps>;
        Transition?: React.ElementType;
        Tooltip?: React.ElementType;
        Arrow?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `slotProps` prop.
     * It's recommended to use the `slotProps` prop instead, as `componentsProps` will be deprecated in the future.
     *
     * @default {}
     */
    componentsProps?: {
        popper?: Partial<PopperProps> & TooltipComponentsPropsOverrides;
        transition?: TransitionProps & TooltipComponentsPropsOverrides;
        tooltip?: React.HTMLProps<HTMLDivElement> & MUIStyledCommonProps & TooltipComponentsPropsOverrides;
        arrow?: React.HTMLProps<HTMLSpanElement> & MUIStyledCommonProps & TooltipComponentsPropsOverrides;
    };
    /**
     * Set to `true` if the `title` acts as an accessible description.
     * By default the `title` acts as an accessible label for the child.
     * @default false
     */
    describeChild?: boolean;
    /**
     * Do not respond to focus-visible events.
     * @default false
     */
    disableFocusListener?: boolean;
    /**
     * Do not respond to hover events.
     * @default false
     */
    disableHoverListener?: boolean;
    /**
     * Makes a tooltip not interactive, i.e. it will close when the user
     * hovers over the tooltip before the `leaveDelay` is expired.
     * @default false
     */
    disableInteractive?: boolean;
    /**
     * Do not respond to long press touch events.
     * @default false
     */
    disableTouchListener?: boolean;
    /**
     * The number of milliseconds to wait before showing the tooltip.
     * This prop won't impact the enter touch delay (`enterTouchDelay`).
     * @default 100
     */
    enterDelay?: number;
    /**
     * The number of milliseconds to wait before showing the tooltip when one was already recently opened.
     * @default 0
     */
    enterNextDelay?: number;
    /**
     * The number of milliseconds a user must touch the element before showing the tooltip.
     * @default 700
     */
    enterTouchDelay?: number;
    /**
     * If `true`, the tooltip follow the cursor over the wrapped element.
     * @default false
     */
    followCursor?: boolean;
    /**
     * This prop is used to help implement the accessibility logic.
     * If you don't provide this prop. It falls back to a randomly generated id.
     */
    id?: string;
    /**
     * The number of milliseconds to wait before hiding the tooltip.
     * This prop won't impact the leave touch delay (`leaveTouchDelay`).
     * @default 0
     */
    leaveDelay?: number;
    /**
     * The number of milliseconds after the user stops touching an element before hiding the tooltip.
     * @default 1500
     */
    leaveTouchDelay?: number;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {React.SyntheticEvent} event The event source of the callback.
     */
    onClose?: (event: React.SyntheticEvent | Event) => void;
    /**
     * Callback fired when the component requests to be open.
     *
     * @param {React.SyntheticEvent} event The event source of the callback.
     */
    onOpen?: (event: React.SyntheticEvent) => void;
    /**
     * If `true`, the component is shown.
     */
    open?: boolean;
    /**
     * Tooltip placement.
     * @default 'bottom'
     */
    placement?: 'bottom-end' | 'bottom-start' | 'bottom' | 'left-end' | 'left-start' | 'left' | 'right-end' | 'right-start' | 'right' | 'top-end' | 'top-start' | 'top';
    /**
     * The component used for the popper.
     * @default Popper
     */
    PopperComponent?: React.JSXElementConstructor<PopperProps>;
    /**
     * Props applied to the [`Popper`](/material-ui/api/popper/) element.
     * @default {}
     */
    PopperProps?: Partial<PopperProps>;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `componentsProps` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slotProps?: {
        popper?: Partial<PopperProps> & TooltipComponentsPropsOverrides;
        transition?: TransitionProps & TooltipComponentsPropsOverrides;
        tooltip?: React.HTMLProps<HTMLDivElement> & MUIStyledCommonProps<Theme> & TooltipComponentsPropsOverrides;
        arrow?: React.HTMLProps<HTMLSpanElement> & MUIStyledCommonProps<Theme> & TooltipComponentsPropsOverrides;
    };
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `components` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slots?: {
        popper?: React.ElementType<PopperProps>;
        transition?: React.ElementType;
        tooltip?: React.ElementType;
        arrow?: React.ElementType;
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Tooltip title. Zero-length titles string, undefined, null and false are never displayed.
     */
    title: React.ReactNode;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Grow
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     */
    TransitionProps?: TransitionProps;
};
declare const Tooltip: (props: TooltipProps) => React.JSX.Element;

type TableProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the table, normally `TableHead` and `TableBody`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableClasses>;
    /**
     * Allows TableCells to inherit padding of the Table.
     * @default 'normal'
     */
    padding?: 'normal' | 'checkbox' | 'none';
    /**
     * Allows TableCells to inherit size of the Table.
     * @default 'medium'
     */
    size?: 'small' | 'medium';
    /**
     * Set the header sticky.
     *
     *  It doesn't work with IE11.
     * @default false
     */
    stickyHeader?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Table: (props: TableProps) => React.JSX.Element;

type TableBodyProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `TableRow`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableBodyClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableBody: (props: TableBodyProps) => React.JSX.Element;

type TableCellProps = PropsWithChildren & {
    key?: string;
    /**
    * Set the text-align on the table cell content.
    *
    * Monetary or generally number fields **should be right aligned** as that allows
    * you to add them up quickly in your head without having to worry about decimals.
    * @default 'inherit'
    */
    align?: 'inherit' | 'left' | 'center' | 'right' | 'justify';
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableCellClasses>;
    /**
     * The component used for the root node.
     * Either a string to use a HTML element or a component.
     */
    component?: React.ElementType<TableCellBaseProps>;
    /**
     * Sets the padding applied to the cell.
     * The prop defaults to the value (`'default'`) inherited from the parent Table component.
     */
    padding?: 'normal' | 'checkbox' | 'none';
    /**
     * Set scope attribute.
     */
    scope?: TableCellBaseProps['scope'];
    /**
     * Specify the size of the cell.
     * The prop defaults to the value (`'medium'`) inherited from the parent Table component.
     */
    size?: 'small' | 'medium';
    /**
     * Set aria-sort direction.
     */
    sortDirection?: SortDirection;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Specify the cell type.
     * The prop defaults to the value inherited from the parent TableHead, TableBody, or TableFooter components.
     */
    variant?: 'head' | 'body' | 'footer';
    colSpan?: number;
};
declare const TableCell: (props: TableCellProps) => React.JSX.Element;

type TableContainerProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component, normally `Table`.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableContainerClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const TableContainer: (props: TableContainerProps) => React.JSX.Element;

type TableFooterProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component, normally `TableRow`.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableFooterClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableFooter: (props: TableFooterProps) => React.JSX.Element;

type TableHeadProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component, normally `TableRow`.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableHeadClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const TableHead: (props: TableHeadProps) => React.JSX.Element;

type TableRowProps = PropsWithChildren & {
    key?: React.Key;
    /**
  * Should be valid `<tr>` children such as `TableCell`.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableRowClasses>;
    /**
     * If `true`, the table row will shade on hover.
     * @default false
     */
    hover?: boolean;
    /**
     * If `true`, the table row will have the selected shading.
     * @default false
     */
    selected?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const TableRow: (props: TableRowProps) => React.JSX.Element;

type TableSortLabelProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, the label will have the active styling (should be true for the sorted column).
    * @default false
    */
    active?: boolean;
    /**
     * Label contents, the arrow will be appended automatically.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TableSortLabelClasses>;
    /**
     * The current sort direction.
     * @default 'asc'
     */
    direction?: 'asc' | 'desc';
    /**
     * Hide sort icon when active is false.
     * @default false
     */
    hideSortIcon?: boolean;
    /**
     * Sort icon to use.
     * @default ArrowDownwardIcon
     */
    IconComponent?: React.JSXElementConstructor<{
        className: string;
    }>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
};
declare const TableSortLabel: (props: TableSortLabelProps) => React.JSX.Element;

type TablePaginationProps = PropsWithChildren & {
    key?: string;
    /**
    * The component used for displaying the actions.
    * Either a string to use a HTML element or a component.
    * @default TablePaginationActions
    */
    ActionsComponent?: React.ElementType<TablePaginationActionsProps>;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TablePaginationClasses>;
    /**
     * The total number of rows.
     *
     * To enable server side pagination for an unknown number of items, provide -1.
     */
    count: number;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Accepts a function which returns a string value that provides a user-friendly name for the current page.
     * This is important for screen reader users.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @param {string} type The link or button type to format ('first' | 'last' | 'next' | 'previous').
     * @returns {string}
     * @default function defaultGetAriaLabel(type) {
     *   return `Go to ${type} page`;
     * }
     */
    getItemAriaLabel?: (type: 'first' | 'last' | 'next' | 'previous') => string;
    /**
     * Customize the displayed rows label. Invoked with a `{ from, to, count, page }`
     * object.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @default function defaultLabelDisplayedRows({ from, to, count }) {
     *   return `${from}�${to} of ${count !== -1 ? count : `more than ${to}`}`;
     * }
     */
    labelDisplayedRows?: (paginationInfo: LabelDisplayedRowsArgs) => React.ReactNode;
    /**
     * Customize the rows per page label.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @default 'Rows per page:'
     */
    labelRowsPerPage?: React.ReactNode;
    /**
     * Callback fired when the page is changed.
     *
     * @param {React.MouseEvent<HTMLButtonElement> | null} event The event source of the callback.
     * @param {number} page The page selected.
     */
    onPageChange: (event: React.MouseEvent<HTMLButtonElement> | null, page: number) => void;
    /**
     * Callback fired when the number of rows per page is changed.
     *
     * @param {React.ChangeEvent<HTMLTextAreaElement | HTMLInputElement>} event The event source of the callback.
     */
    onRowsPerPageChange?: React.ChangeEventHandler<HTMLTextAreaElement | HTMLInputElement>;
    /**
     * The zero-based index of the current page.
     */
    page: number;
    /**
     * The number of rows per page.
     *
     * Set -1 to display all the rows.
     */
    rowsPerPage: number;
    /**
     * Customizes the options of the rows per page select field. If less than two options are
     * available, no select field will be displayed.
     * Use -1 for the value with a custom label to show all the rows.
     * @default [10, 25, 50, 100]
     */
    rowsPerPageOptions?: ReadonlyArray<number | {
        value: number;
        label: string;
    }>;
    /**
     * If `true`, show the first-page button.
     * @default false
     */
    showFirstButton?: boolean;
    /**
     * If `true`, show the last-page button.
     * @default false
     */
    showLastButton?: boolean;
    /**
     * The props used for each slot inside the TablePagination.
     * @default {}
     */
    slotProps?: {
        actions?: TablePaginationActionsProps['slotProps'];
        select?: Partial<SelectProps>;
    };
    /**
     * The components used for each slot inside the TablePagination.
     * Either a string to use a HTML element or a component.
     * @default {}
     */
    slots?: {
        actions?: TablePaginationActionsProps['slots'];
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const TablePagination: (props: TablePaginationProps) => React.JSX.Element;

type GridProps = PropsWithChildren & {
    key?: string;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<GridClasses>;
    /**
     * The number of columns.
     * @default 12
     */
    columns?: ResponsiveStyleValue<number>;
    /**
     * Defines the horizontal space between the type `item` components.
     * It overrides the value of the `spacing` prop.
     */
    columnSpacing?: ResponsiveStyleValue<GridSpacing>;
    /**
     * If `true`, the component will have the flex *container* behavior.
     * You should be wrapping *items* with a *container*.
     * @default false
     */
    container?: boolean;
    /**
     * Defines the `flex-direction` style property.
     * It is applied for all screen sizes.
     * @default 'row'
     */
    direction?: ResponsiveStyleValue<GridDirection>;
    /**
     * If `true`, the component will have the flex *item* behavior.
     * You should be wrapping *items* with a *container*.
     * @default false
     */
    item?: boolean;
    /**
     * Defines the vertical space between the type `item` components.
     * It overrides the value of the `spacing` prop.
     */
    rowSpacing?: ResponsiveStyleValue<GridSpacing>;
    /**
     * Defines the space between the type `item` components.
     * It can only be used on a type `container` component.
     * @default 0
     */
    spacing?: ResponsiveStyleValue<GridSpacing>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Defines the `flex-wrap` style property.
     * It's applied for all screen sizes.
     * @default 'wrap'
     */
    wrap?: GridWrap;
    /**
     * If `true`, it sets `min-width: 0` on the item.
     * Refer to the limitations section of the documentation to better understand the use case.
     * @default false
     */
    zeroMinWidth?: boolean;
    /**
   * If a number, it sets the number of columns the grid item uses.
   * It can't be greater than the total number of columns of the container (12 by default).
   * If 'auto', the grid item's width matches its content.
   * If false, the prop is ignored.
   * If true, the grid item's width grows to use the space available in the grid container.
   * The value is applied for the `lg` breakpoint and wider screens if not overridden.
   * @default false
   */
    lg?: boolean | GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `md` breakpoint and wider screens if not overridden.
     * @default false
     */
    md?: boolean | GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `sm` breakpoint and wider screens if not overridden.
     * @default false
     */
    sm?: boolean | GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for the `xl` breakpoint and wider screens if not overridden.
     * @default false
     */
    xl?: boolean | GridSize;
    /**
     * If a number, it sets the number of columns the grid item uses.
     * It can't be greater than the total number of columns of the container (12 by default).
     * If 'auto', the grid item's width matches its content.
     * If false, the prop is ignored.
     * If true, the grid item's width grows to use the space available in the grid container.
     * The value is applied for all the screen sizes with the lowest priority.
     * @default false
     */
    xs?: boolean | GridSize;
    justifyContent?: any;
    alignItems?: any;
};
declare const Grid: (props: GridProps) => React.JSX.Element;

type DrawerProps = PropsWithChildren & {
    key?: string;
    /**
   * Side from which the drawer will appear.
   * @default 'left'
   */
    anchor?: 'left' | 'top' | 'right' | 'bottom';
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DrawerClasses>;
    /**
     * The elevation of the drawer.
     * @default 16
     */
    elevation?: number;
    /**
     * Props applied to the [`Modal`](/material-ui/api/modal/) element.
     * @default {}
     */
    ModalProps?: Partial<ModalProps>;
    /**
     * Callback fired when the component requests to be closed.
     * The `reason` parameter can optionally be used to control the response to `onClose`.
     *
     * @param {object} event The event source of the callback.
     * @param {string} reason Can be: `"escapeKeyDown"`, `"backdropClick"`.
     */
    onClose?: ModalProps['onClose'];
    /**
     * If `true`, the component is shown.
     * @default false
     */
    open?: boolean;
    /**
     * Props applied to the [`Paper`](/material-ui/api/paper/) element.
     * @default {}
     */
    PaperProps?: Partial<PaperProps$1<React.ElementType>>;
    /**
     * Props applied to the [`Slide`](/material-ui/api/slide/) element.
     */
    SlideProps?: Partial<SlideProps$1>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The duration for the transition, in milliseconds.
     * You may specify a single timeout for all transitions, or individually with an object.
     * @default {
     *   enter: theme.transitions.duration.enteringScreen,
     *   exit: theme.transitions.duration.leavingScreen,
     * }
     */
    transitionDuration?: TransitionProps['timeout'];
    /**
     * The variant to use.
     * @default 'temporary'
     */
    variant?: 'permanent' | 'persistent' | 'temporary';
};
declare const Drawer: (props: DrawerProps) => React.JSX.Element;

type SwipeableDrawerProps = PropsWithChildren & {
    key?: string;
    /**
   * If set to true, the swipe event will open the drawer even if the user begins the swipe on one of the drawer's children.
   * This can be useful in scenarios where the drawer is partially visible.
   * You can customize it further with a callback that determines which children the user can drag over to open the drawer
   * (for example, to ignore other elements that handle touch move events, like sliders).
   *
   * @param {TouchEvent} event The 'touchstart' event
   * @param {HTMLDivElement} swipeArea The swipe area element
   * @param {HTMLDivElement} paper The drawer's paper element
   *
   * @default false
   */
    allowSwipeInChildren?: boolean | ((e: TouchEvent, swipeArea: HTMLDivElement, paper: HTMLDivElement) => boolean);
    /**
     * Disable the backdrop transition.
     * This can improve the FPS on low-end devices.
     * @default false
     */
    disableBackdropTransition?: boolean;
    /**
     * If `true`, touching the screen near the edge of the drawer will not slide in the drawer a bit
     * to promote accidental discovery of the swipe gesture.
     * @default false
     */
    disableDiscovery?: boolean;
    /**
     * If `true`, swipe to open is disabled. This is useful in browsers where swiping triggers
     * navigation actions. Swipe to open is disabled on iOS browsers by default.
     * @default typeof navigator !== 'undefined' && /iPad|iPhone|iPod/.test(navigator.userAgent)
     */
    disableSwipeToOpen?: boolean;
    /**
     * Affects how far the drawer must be opened/closed to change its state.
     * Specified as percent (0-1) of the width of the drawer
     * @default 0.52
     */
    hysteresis?: number;
    /**
     * Defines, from which (average) velocity on, the swipe is
     * defined as complete although hysteresis isn't reached.
     * Good threshold is between 250 - 1000 px/s
     * @default 450
     */
    minFlingVelocity?: number;
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {React.SyntheticEvent<{}>} event The event source of the callback.
     */
    onClose: React.ReactEventHandler<{}>;
    /**
     * Callback fired when the component requests to be opened.
     *
     * @param {React.SyntheticEvent<{}>} event The event source of the callback.
     */
    onOpen: React.ReactEventHandler<{}>;
    /**
     * If `true`, the component is shown.
     * @default false
     */
    open?: boolean;
    /**
     * The element is used to intercept the touch events on the edge.
     */
    SwipeAreaProps?: object;
    /**
     * The width of the left most (or right most) area in `px` that
     * the drawer can be swiped open from.
     * @default 20
     */
    swipeAreaWidth?: number;
    anchor?: "left" | "right" | "top" | "bottom" | undefined;
};
declare const SwipeableDrawer: (props: SwipeableDrawerProps) => React.JSX.Element;

type StepperProps = PropsWithChildren & {
    key?: string;
    /**
   * Set the active step (zero based index).
   * Set to -1 to disable all the steps.
   * @default 0
   */
    activeStep?: number;
    /**
     * If set to 'true' and orientation is horizontal,
     * then the step label will be positioned under the icon.
     * @default false
     */
    alternativeLabel?: boolean;
    /**
     * Two or more `<Step />` components.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepperClasses>;
    /**
     * An element to be placed between each step.
     * @default <StepConnector />
     */
    connector?: React.ReactElement<any, any> | null;
    /**
     * If set the `Stepper` will not assist in controlling steps for linear flow.
     * @default false
     */
    nonLinear?: boolean;
    /**
     * The component orientation (layout flow direction).
     * @default 'horizontal'
     */
    orientation?: Orientation;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Stepper: (props: StepperProps) => React.JSX.Element;

type TabsProps$1 = PropsWithChildren & {
    key?: string;
    /**
   * Callback fired when the component mounts.
   * This is useful when you want to trigger an action programmatically.
   * It supports two actions: `updateIndicator()` and `updateScrollButtons()`
   *
   * @param {object} actions This object contains all possible actions
   * that can be triggered programmatically.
   */
    action?: React.Ref<TabsActions>;
    /**
     * If `true`, the scroll buttons aren't forced hidden on mobile.
     * By default the scroll buttons are hidden on mobile and takes precedence over `scrollButtons`.
     * @default false
     */
    allowScrollButtonsMobile?: boolean;
    /**
     * The label for the Tabs as a string.
     */
    'aria-label'?: string;
    /**
     * An id or list of ids separated by a space that label the Tabs.
     */
    'aria-labelledby'?: string;
    /**
     * If `true`, the tabs are centered.
     * This prop is intended for large views.
     * @default false
     */
    centered?: boolean;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TabsClasses>;
    /**
     * The components used for each slot inside.
     * @default {}
     */
    slots?: {
        StartScrollButtonIcon?: React.ElementType;
        EndScrollButtonIcon?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     * @default {}
     */
    /**
     * Determines the color of the indicator.
     * @default 'primary'
     */
    indicatorColor?: 'secondary' | 'primary';
    /**
     * Callback fired when the value changes.
     *
     * @param {React.SyntheticEvent} event The event source of the callback. **Warning**: This is a generic event not a change event.
     * @param {any} value We default to the index of the child (number)
     */
    onChange?: (event: React.SyntheticEvent, value: any) => void;
    /**
     * The component orientation (layout flow direction).
     * @default 'horizontal'
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * The component used to render the scroll buttons.
     * @default TabScrollButton
     */
    ScrollButtonComponent?: React.ElementType;
    /**
     * Determine behavior of scroll buttons when tabs are set to scroll:
     *
     * - `auto` will only present them when not all the items are visible.
     * - `true` will always present them.
     * - `false` will never present them.
     *
     * By default the scroll buttons are hidden on mobile.
     * This behavior can be disabled with `allowScrollButtonsMobile`.
     * @default 'auto'
     */
    scrollButtons?: 'auto' | true | false;
    /**
     * If `true` the selected tab changes on focus. Otherwise it only
     * changes on activation.
     */
    selectionFollowsFocus?: boolean;
    /**
     * Props applied to the tab indicator element.
     * @default  {}
     */
    TabIndicatorProps?: React.HTMLAttributes<HTMLDivElement> & {
        sx?: SxProps<Theme>;
    };
    /**
     * Props applied to the [`TabScrollButton`](/material-ui/api/tab-scroll-button/) element.
     * @default {}
     */
    TabScrollButtonProps?: Partial<TabScrollButtonProps>;
    /**
     * Determines the color of the `Tab`.
     * @default 'primary'
     */
    textColor?: 'secondary' | 'primary' | 'inherit';
    /**
     * The value of the currently selected `Tab`.
     * If you don't want any selected `Tab`, you can set this prop to `false`.
     */
    value?: any;
    /**
     *  Determines additional display behavior of the tabs:
     *
     *  - `scrollable` will invoke scrolling properties and allow for horizontally
     *  scrolling (or swiping) of the tab bar.
     *  - `fullWidth` will make the tabs grow to use all the available space,
     *  which should be used for small views, like on mobile.
     *  - `standard` will render the default state.
     * @default 'standard'
     */
    variant?: 'standard' | 'scrollable' | 'fullWidth';
    /**
     * If `true`, the scrollbar is visible. It can be useful when displaying
     * a long vertical list of tabs.
     * @default false
     */
    visibleScrollbar?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Tabs: (props: TabsProps$1) => React.JSX.Element;

type TabProps = PropsWithChildren & {
    key?: string;
    /**
    * This prop isn't supported.
    * Use the `component` prop if you need to change the children structure.
    */
    children?: null;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TabClasses>;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the  keyboard focus ripple is disabled.
     * @default false
     */
    disableFocusRipple?: boolean;
    /**
     * The icon to display.
     */
    icon?: string | React.ReactElement;
    /**
     * The position of the icon relative to the label.
     * @default 'top'
     */
    iconPosition?: 'top' | 'bottom' | 'start' | 'end';
    /**
     * The label element.
     */
    label?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * You can provide your own value. Otherwise, we fallback to the child position index.
     */
    value?: any;
    /**
     * Tab labels appear in a single row.
     * They can use a second line if needed.
     * @default false
     */
    wrapped?: boolean;
};
declare const Tab: (props: TabProps) => React.JSX.Element;

type StepProps$1 = PropsWithChildren & {
    key?: string;
    /**
     * Sets the step as active. Is passed to child components.
     */
    active?: boolean;
    /**
     * Should be `Step` sub-components such as `StepLabel`, `StepContent`.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepClasses>;
    /**
     * Mark the step as completed. Is passed to child components.
     */
    completed?: boolean;
    /**
     * If `true`, the step is disabled, will also disable the button if
     * `StepButton` is a child of `Step`. Is passed to child components.
     */
    disabled?: boolean;
    /**
     * Expand the step.
     * @default false
     */
    expanded?: boolean;
    /**
     * The position of the step.
     * The prop defaults to the value inherited from the parent Stepper component.
     */
    index?: number;
    /**
     * If `true`, the Step is displayed as rendered last.
     * The prop defaults to the value inherited from the parent Stepper component.
     */
    last?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Step: (props: StepProps$1) => React.JSX.Element;

type StepProps = PropsWithChildren & {
    key?: string;
    /**
   * Can be a `StepLabel` or a node to place inside `StepLabel` as children.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepButtonClasses>;
    /**
     * The icon displayed by the step label.
     */
    icon?: React.ReactNode;
    /**
     * The optional node to display.
     */
    optional?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const StepButton: (props: StepProps) => React.JSX.Element;

type StepLabelProps = PropsWithChildren & {
    key?: string;
    /**
    * In most cases will simply be a string containing a title for the label.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepLabelClasses>;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    componentsProps?: {
        /**
         * Props applied to the label element.
         * @default {}
         */
        label?: React.HTMLProps<HTMLSpanElement>;
    };
    /**
     * If `true`, the step is marked as failed.
     * @default false
     */
    error?: boolean;
    /**
     * Override the default label of the step icon.
     */
    icon?: React.ReactNode;
    /**
     * The optional node to display.
     */
    optional?: React.ReactNode;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    slotProps?: {
        /**
         * Props applied to the label element.
         * @default {}
         */
        label?: React.HTMLProps<HTMLSpanElement>;
    };
    /**
     * The component to render in place of the [`StepIcon`](/material-ui/api/step-icon/).
     */
    StepIconComponent?: React.ElementType<StepIconProps>;
    /**
     * Props applied to the [`StepIcon`](/material-ui/api/step-icon/) element.
     */
    StepIconProps?: Partial<StepIconProps>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const StepLabel: (props: StepLabelProps) => React.JSX.Element;

type StepContentProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<StepContentClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Collapse
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    /**
     * Adjust the duration of the content expand transition.
     * Passed as a prop to the transition component.
     *
     * Set to 'auto' to automatically calculate transition time based on height.
     * @default 'auto'
     */
    transitionDuration?: TransitionProps['timeout'] | 'auto';
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     */
    TransitionProps?: TransitionProps;
};
declare const StepContent: (props: StepContentProps) => React.JSX.Element;

type TabsProps = PropsWithChildren & {
    key?: string;
    /**
    * Set the text-align on the component.
    * @default 'inherit'
    */
    align?: 'inherit' | 'left' | 'center' | 'right' | 'justify';
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<TypographyClasses>;
    /**
     * If `true`, the text will have a bottom margin.
     * @default false
     */
    gutterBottom?: boolean;
    /**
     * If `true`, the text will not wrap, but instead will truncate with a text overflow ellipsis.
     *
     * Note that text overflow can only happen with block or inline-block level elements
     * (the element needs to have a width in order to overflow).
     * @default false
     */
    noWrap?: boolean;
    /**
     * If `true`, the element will be a paragraph element.
     * @default false
     */
    paragraph?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * Applies the theme typography styles.
     * @default 'body1'
     */
    variant?: OverridableStringUnion<Variant | 'inherit', TypographyPropsVariantOverrides>;
    /**
     * The component maps the variant prop to a range of different HTML element types.
     * For instance, subtitle1 to `<h6>`.
     * If you wish to change that mapping, you can provide your own.
     * Alternatively, you can use the `component` prop.
     * @default {
     *   h1: 'h1',
     *   h2: 'h2',
     *   h3: 'h3',
     *   h4: 'h4',
     *   h5: 'h5',
     *   h6: 'h6',
     *   subtitle1: 'h6',
     *   subtitle2: 'h6',
     *   body1: 'p',
     *   body2: 'p',
     *   inherit: 'p',
     * }
     */
    variantMapping?: Partial<Record<OverridableStringUnion<Variant | 'inherit', TypographyPropsVariantOverrides>, string>>;
    color?: string;
    component?: React.ElementType;
    display?: any;
};
declare const Typography: (props: TabsProps) => React.JSX.Element;

type AccordionProps = PropsWithChildren & {
    key?: string;
    /**
            * The content of the component.
            */
    children: NonNullable<React.ReactNode>;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AccordionClasses>;
    /**
     * If `true`, expands the accordion by default.
     * @default false
     */
    defaultExpanded?: boolean;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, it removes the margin between two expanded accordion items and the increase of height.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * If `true`, expands the accordion, otherwise collapse it.
     * Setting this prop enables control over the accordion.
     */
    expanded?: boolean;
    /**
     * Callback fired when the expand/collapse state is changed.
     *
     * @param {React.SyntheticEvent} event The event source of the callback. **Warning**: This is a generic event not a change event.
     * @param {boolean} expanded The `expanded` state of the accordion.
     */
    onChange?: (event: React.SyntheticEvent, expanded: boolean) => void;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @deprecated Use `slots.transition` instead. This prop will be removed in v7. [How to migrate](/material-ui/migration/migrating-from-deprecated-apis/).
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children?: React.ReactElement<any, any>;
    }>;
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     * @deprecated Use `slotProps.transition` instead. This prop will be removed in v7. [How to migrate](/material-ui/migration/migrating-from-deprecated-apis/).
     */
    TransitionProps?: TransitionProps;
    slots?: AccordionSlots$1;
    slotProps?: {
        transition: SlotProps<React.ElementType<TransitionProps>, AccordionTransitionSlotPropsOverrides, AccordionOwnerState>;
    };
};
interface AccordionSlots {
    /**
     * The component that renders the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Collapse
     */
    transition?: React.JSXElementConstructor<TransitionProps & {
        children?: React.ReactElement<any, any>;
    }>;
}
declare const Accordion: (props: AccordionProps) => React.JSX.Element;

type AccordionDetailsProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AccordionDetailsClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const AccordionDetails: (props: AccordionDetailsProps) => React.JSX.Element;

type AccordionSummaryProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AccordionSummaryClasses>;
    /**
     * The icon to display as the expand indicator.
     */
    expandIcon?: React.ReactNode;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const AccordionSummary: (props: AccordionSummaryProps) => React.JSX.Element;

type CardProps = PropsWithChildren & {
    key?: string;
    /**
   * Override or extend the styles applied to the component.
   */
    classes?: Partial<CardClasses>;
    /**
     * If `true`, the card will use raised styling.
     * @default false
     */
    raised?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    variant?: "outlined" | "elevation";
};
declare const Card: (props: CardProps) => React.JSX.Element;

type CardActionsProps = PropsWithChildren & {
    key?: string;
    /**
     * The content of the component.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<CardActionsClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * If `true`, the actions do not have additional margin.
     * @default false
     */
    disableSpacing?: boolean;
};
declare const CardActions: (props: CardActionsProps) => React.JSX.Element;

type CardContentProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<CardContentClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const CardContent: (props: CardContentProps) => React.JSX.Element;

type LinkProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<LinkClasses>;
    /**
     * The color of the link.
     * @default 'primary'
     */
    color?: TypographyOwnProps['color'];
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * `classes` prop applied to the [`Typography`](/material-ui/api/typography/) element.
     */
    TypographyClasses?: TypographyOwnProps['classes'];
    /**
     * Controls when the link should have an underline.
     * @default 'always'
     */
    underline?: 'none' | 'hover' | 'always';
    /**
     * Applies the theme typography styles.
     * @default 'inherit'
     */
    variant?: TypographyOwnProps['variant'];
    href?: string;
};
declare const Link: (props: LinkProps) => React.JSX.Element;

type AppBarProps = PropsWithChildren & {
    key?: string;
    /**
  * Override or extend the styles applied to the component.
  */
    classes?: Partial<AppBarClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<PropTypes.Color | 'transparent' | 'error' | 'info' | 'success' | 'warning', AppBarPropsColorOverrides>;
    /**
     * If true, the `color` prop is applied in dark mode.
     * @default false
     */
    enableColorOnDark?: boolean;
    /**
     * The positioning type. The behavior of the different options is described
     * [in the MDN web docs](https://developer.mozilla.org/en-US/docs/Learn/CSS/CSS_layout/Positioning).
     * Note: `sticky` is not universally supported and will fall back to `static` when unavailable.
     * @default 'fixed'
     */
    position?: 'fixed' | 'absolute' | 'sticky' | 'static' | 'relative';
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const AppBar: (props: AppBarProps) => React.JSX.Element;

type AlertProps = PropsWithChildren & {
    key?: string;
    /**
   * The action to display. It renders after the message, at the end of the alert.
   */
    action?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AlertClasses>;
    /**
     * Override the default label for the *close popup* icon button.
     *
     * For localization purposes, you can use the provided [translations](/material-ui/guides/localization/).
     * @default 'Close'
     */
    closeText?: string;
    /**
     * The color of the component. Unless provided, the value is taken from the `severity` prop.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     */
    color?: OverridableStringUnion<AlertColor, AlertPropsColorOverrides>;
    /**
     * The components used for each slot inside.
     *
     * @deprecated use the `slots` prop instead. This prop will be removed in v7. [How to migrate](/material-ui/migration/migrating-from-deprecated-apis/).
     *
     * @default {}
     */
    components?: {
        CloseButton?: React.ElementType;
        CloseIcon?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * @deprecated use the `slotProps` prop instead. This prop will be removed in v7. [How to migrate](/material-ui/migration/migrating-from-deprecated-apis/).
     *
     * @default {}
     */
    componentsProps?: {
        closeButton?: IconButtonProps;
        closeIcon?: SvgIconProps;
    };
    /**
     * The severity of the alert. This defines the color and icon used.
     * @default 'success'
     */
    severity?: OverridableStringUnion<AlertColor, AlertPropsColorOverrides>;
    /**
     * Override the icon displayed before the children.
     * Unless provided, the icon is mapped to the value of the `severity` prop.
     * Set to `false` to remove the `icon`.
     */
    icon?: React.ReactNode;
    /**
     * The ARIA role attribute of the element.
     * @default 'alert'
     */
    role?: string;
    /**
     * The component maps the `severity` prop to a range of different icons,
     * for instance success to `<SuccessOutlined>`.
     * If you wish to change this mapping, you can provide your own.
     * Alternatively, you can use the `icon` prop to override the icon displayed.
     */
    iconMapping?: Partial<Record<OverridableStringUnion<AlertColor, AlertPropsColorOverrides>, React.ReactNode>>;
    /**
     * Callback fired when the component requests to be closed.
     * When provided and no `action` prop is set, a close icon button is displayed that triggers the callback when clicked.
     * @param {React.SyntheticEvent} event The event source of the callback.
     */
    onClose?: (event: React.SyntheticEvent) => void;
    /**
     * The variant to use.
     * @default 'standard'
     */
    variant?: OverridableStringUnion<'standard' | 'filled' | 'outlined', AlertPropsVariantOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const Alert: (props: AlertProps) => React.JSX.Element;

type AlertTitleProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<AlertTitleClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const AlertTitle: (props: AlertTitleProps) => React.JSX.Element;

type BackdropProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    */
    children?: React.ReactNode;
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `slots` prop.
     * It's recommended to use the `slots` prop instead.
     *
     * @default {}
     */
    components?: {
        Root?: React.ElementType;
    };
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `slotProps` prop.
     * It's recommended to use the `slotProps` prop instead, as `componentsProps` will be deprecated in the future.
     *
     * @default {}
     */
    componentsProps?: {
        root?: React.HTMLAttributes<HTMLDivElement> & BackdropComponentsPropsOverrides;
    };
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<BackdropClasses>;
    /**
     * If `true`, the backdrop is invisible.
     * It can be used when rendering a popover or a custom select component.
     * @default false
     */
    invisible?: boolean;
    /**
     * If `true`, the component is shown.
     */
    open: boolean;
    /**
     * The extra props for the slot components.
     * You can override the existing props or add new ones.
     *
     * This prop is an alias for the `componentsProps` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slotProps?: {
        root?: React.HTMLAttributes<HTMLDivElement> & BackdropComponentsPropsOverrides;
    };
    /**
     * The components used for each slot inside.
     *
     * This prop is an alias for the `components` prop, which will be deprecated in the future.
     *
     * @default {}
     */
    slots?: {
        root?: React.ElementType;
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps$1<Theme$1>;
    /**
     * The duration for the transition, in milliseconds.
     * You may specify a single timeout for all transitions, or individually with an object.
     */
    transitionDuration?: TransitionProps['timeout'];
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Fade
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    onClick?: MouseEventHandler<any>;
};
declare const Backdrop: (props: BackdropProps) => React.JSX.Element;

type DialogProps = PropsWithChildren & {
    key?: string;
    /**
   * The id(s) of the element(s) that describe the dialog.
   */
    'aria-describedby'?: string;
    /**
     * The id(s) of the element(s) that label the dialog.
     */
    'aria-labelledby'?: string;
    /**
     * Dialog children, usually the included sub-components.
     */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DialogClasses>;
    /**
     * If `true`, hitting escape will not fire the `onClose` callback.
     * @default false
     */
    disableEscapeKeyDown?: boolean;
    /**
     * If `true`, the dialog is full-screen.
     * @default false
     */
    fullScreen?: boolean;
    /**
     * If `true`, the dialog stretches to `maxWidth`.
     *
     * Notice that the dialog width grow is limited by the default margin.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * Determine the max-width of the dialog.
     * The dialog width grows with the size of the screen.
     * Set to `false` to disable `maxWidth`.
     * @default 'sm'
     */
    maxWidth?: Breakpoint | false;
    /**
     * Callback fired when the backdrop is clicked.
     * @deprecated Use the `onClose` prop with the `reason` argument to handle the `backdropClick` events.
     */
    onBackdropClick?: ModalProps['onBackdropClick'];
    /**
     * Callback fired when the component requests to be closed.
     *
     * @param {object} event The event source of the callback.
     * @param {string} reason Can be: `"escapeKeyDown"`, `"backdropClick"`.
     */
    onClose?: ModalProps['onClose'];
    /**
     * If `true`, the component is shown.
     */
    open: ModalProps['open'];
    /**
     * The component used to render the body of the dialog.
     * @default Paper
     */
    PaperComponent?: React.JSXElementConstructor<PaperProps$1>;
    /**
     * Props applied to the [`Paper`](/material-ui/api/paper/) element.
     * @default {}
     */
    PaperProps?: Partial<PaperProps$1<React.ElementType>>;
    /**
     * Determine the container for scrolling the dialog.
     * @default 'paper'
     */
    scroll?: 'body' | 'paper';
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The component used for the transition.
     * [Follow this guide](/material-ui/transitions/#transitioncomponent-prop) to learn more about the requirements for this component.
     * @default Fade
     */
    TransitionComponent?: React.JSXElementConstructor<TransitionProps & {
        children: React.ReactElement<any, any>;
    }>;
    /**
     * The duration for the transition, in milliseconds.
     * You may specify a single timeout for all transitions, or individually with an object.
     * @default {
     *   enter: theme.transitions.duration.enteringScreen,
     *   exit: theme.transitions.duration.leavingScreen,
     * }
     */
    transitionDuration?: TransitionProps['timeout'];
    /**
     * Props applied to the transition element.
     * By default, the element is based on this [`Transition`](https://reactcommunity.org/react-transition-group/transition/) component.
     */
    TransitionProps?: TransitionProps;
};
declare const Dialog: (props: DialogProps) => React.JSX.Element;

type DialogActionsProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DialogActionsClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * If `true`, the actions do not have additional margin.
     * @default false
     */
    disableSpacing?: boolean;
};
declare const DialogActions: (props: DialogActionsProps) => React.JSX.Element;

type DialogContentProps = PropsWithChildren & {
    key?: string;
    /**
  * The content of the component.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DialogContentClasses>;
    /**
     * Display the top and bottom dividers.
     * @default false
     */
    dividers?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const DialogContent: (props: DialogContentProps) => React.JSX.Element;

type DialogContentTextProps = PropsWithChildren & {
    key?: string;
    /**
    * Override or extend the styles applied to the component.
    */
    classes?: Partial<DialogContentTextClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const DialogContentText: (props: DialogContentTextProps) => React.JSX.Element;

type DialogTitleProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<DialogTitleClasses>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const DialogTitle: (props: DialogTitleProps) => React.JSX.Element;

type ChipProps = PropsWithChildren & {
    key?: string;
    /**
   * The Avatar element to display.
   */
    avatar?: React.ReactElement;
    /**
     * This prop isn't supported.
     * Use the `component` prop if you need to change the children structure.
     */
    children?: null;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ChipClasses>;
    /**
     * If `true`, the chip will appear clickable, and will raise when pressed,
     * even if the onClick prop is not defined.
     * If `false`, the chip will not appear clickable, even if onClick prop is defined.
     * This can be used, for example,
     * along with the component prop to indicate an anchor Chip is clickable.
     * Note: this controls the UI and does not affect the onClick event.
     */
    clickable?: boolean;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'default'
     */
    color?: OverridableStringUnion<'default' | 'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning', ChipPropsColorOverrides>;
    /**
     * Override the default delete icon element. Shown only if `onDelete` is set.
     */
    deleteIcon?: React.ReactElement;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * Icon element.
     */
    icon?: React.ReactElement;
    /**
     * The content of the component.
     */
    label?: React.ReactNode;
    /**
     * Callback fired when the delete icon is clicked.
     * If set, the delete icon will be shown.
     */
    onDelete?: React.EventHandler<any>;
    /**
     * The size of the component.
     * @default 'medium'
     */
    size?: OverridableStringUnion<'small' | 'medium', ChipPropsSizeOverrides>;
    /**
     * If `true`, allows the disabled chip to escape focus.
     * If `false`, allows the disabled chip to receive focus.
     * @default false
     */
    skipFocusWhenDisabled?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     *  @ignore
     */
    tabIndex?: number;
    /**
     * The variant to use.
     * @default 'filled'
     */
    variant?: OverridableStringUnion<'filled' | 'outlined', ChipPropsVariantOverrides>;
    onClick?: MouseEventHandler<any>;
};
declare const Chip: (props: ChipProps) => React.JSX.Element;

type BoxProps = PropsWithChildren & {
    key?: string;
    className?: string;
    style?: React.CSSProperties;
    classes?: Partial<ClassNameMap<string>>;
    sx?: SxProps<Theme>;
    onClick?: MouseEventHandler<any>;
    component?: React.ElementType;
};
declare const Box: (props: BoxProps) => React.JSX.Element;

type ToolbarProps = PropsWithChildren & {
    key?: string;
    /**
  * The Toolbar children, usually a mixture of `IconButton`, `Button` and `Typography`.
  * The Toolbar is a flex container, allowing flex item properties to be used to lay out the children.
  */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<ToolbarClasses>;
    /**
     * If `true`, disables gutter padding.
     * @default false
     */
    disableGutters?: boolean;
    /**
     * The variant to use.
     * @default 'regular'
     */
    variant?: OverridableStringUnion<'regular' | 'dense', ToolbarPropsVariantOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const Toolbar: (props: ToolbarProps) => React.JSX.Element;

type PaperProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<PaperClasses>;
    /**
     * Shadow depth, corresponds to `dp` in the spec.
     * It accepts values between 0 and 24 inclusive.
     * @default 1
     */
    elevation?: number;
    /**
     * If `true`, rounded corners are disabled.
     * @default false
     */
    square?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The variant to use.
     * @default 'elevation'
     */
    variant?: OverridableStringUnion<'elevation' | 'outlined', PaperPropsVariantOverrides>;
};
declare const Paper: (props: PaperProps) => React.JSX.Element;

type FormGroupProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<FormGroupClasses>;
    /**
     * Display group of elements in a compact row.
     * @default false
     */
    row?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
};
declare const FormGroup: (props: FormGroupProps) => React.JSX.Element;

type FormControlProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.HTMLAttributes<HTMLDivElement>['children'];
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<FormControlClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning', FormControlPropsColorOverrides>;
    /**
     * If `true`, the label, input and helper text should be displayed in a disabled state.
     * @default false
     */
    disabled?: boolean;
    /**
     * If `true`, the label is displayed in an error state.
     * @default false
     */
    error?: boolean;
    /**
     * If `true`, the component will take up the full width of its container.
     * @default false
     */
    fullWidth?: boolean;
    /**
     * If `true`, the component is displayed in focused state.
     */
    focused?: boolean;
    /**
     * If `true`, the label is hidden.
     * This is used to increase density for a `FilledInput`.
     * Be sure to add `aria-label` to the `input` element.
     * @default false
     */
    hiddenLabel?: boolean;
    /**
     * If `dense` or `normal`, will adjust vertical spacing of this and contained components.
     * @default 'none'
     */
    margin?: 'dense' | 'normal' | 'none';
    /**
     * If `true`, the label will indicate that the `input` is required.
     * @default false
     */
    required?: boolean;
    /**
     * The size of the component.
     * @default 'medium'
     */
    size?: OverridableStringUnion<'small' | 'medium', FormControlPropsSizeOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The variant to use.
     * @default 'outlined'
     */
    variant?: 'standard' | 'outlined' | 'filled';
    component?: React.ElementType;
};
declare const FormControl: (props: FormControlProps) => React.JSX.Element;

type FormControlLabelProps = PropsWithChildren & {
    key?: string;
    /**
    * If `true`, the component appears selected.
    */
    checked?: boolean;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<FormControlLabelClasses>;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    componentsProps?: {
        /**
         * Props applied to the Typography wrapper of the passed label.
         * This is unused if disableTypography is true.
         * @default {}
         */
        typography?: TypographyProps;
    };
    /**
     * A control element. For instance, it can be a `Radio`, a `Switch` or a `Checkbox`.
     */
    control: React.ReactElement<any, any>;
    /**
     * If `true`, the control is disabled.
     */
    disabled?: boolean;
    /**
     * If `true`, the label is rendered as it is passed without an additional typography node.
     */
    disableTypography?: boolean;
    /**
     * Pass a ref to the `input` element.
     */
    inputRef?: React.Ref<any>;
    /**
     * A text or an element to be used in an enclosing label element.
     */
    label: React.ReactNode;
    /**
     * The position of the label.
     * @default 'end'
     */
    labelPlacement?: 'end' | 'start' | 'top' | 'bottom';
    name?: string;
    /**
     * Callback fired when the state is changed.
     *
     * @param {React.SyntheticEvent} event The event source of the callback.
     * You can pull out the new checked state by accessing `event.target.checked` (boolean).
     */
    onChange?: (event: React.SyntheticEvent, checked: boolean) => void;
    /**
     * If `true`, the label will indicate that the `input` is required.
     */
    required?: boolean;
    /**
     * The props used for each slot inside.
     * @default {}
     */
    slotProps?: {
        /**
         * Props applied to the Typography wrapper of the passed label.
         * This is unused if disableTypography is true.
         * @default {}
         */
        typography?: TypographyProps;
    };
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The value of the component.
     */
    value?: unknown;
};
declare const FormControlLabel: (props: FormControlLabelProps) => React.JSX.Element;

type FormHelperTextProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    *
    * If `' '` is provided, the component reserves one line height for displaying a future message.
    */
    children?: React.ReactNode;
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<FormHelperTextClasses>;
    /**
     * If `true`, the helper text should be displayed in a disabled state.
     */
    disabled?: boolean;
    /**
     * If `true`, helper text should be displayed in an error state.
     */
    error?: boolean;
    /**
     * If `true`, the helper text should use filled classes key.
     */
    filled?: boolean;
    /**
     * If `true`, the helper text should use focused classes key.
     */
    focused?: boolean;
    /**
     * If `dense`, will adjust vertical spacing. This is normally obtained via context from
     * FormControl.
     */
    margin?: 'dense';
    /**
     * If `true`, the helper text should use required classes key.
     */
    required?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The variant to use.
     */
    variant?: OverridableStringUnion<'standard' | 'outlined' | 'filled', FormHelperTextPropsVariantOverrides>;
};
declare const FormHelperText: (props: FormHelperTextProps) => React.JSX.Element;

type FormLabelTextProps = PropsWithChildren & {
    key?: string;
    /**
   * The content of the component.
   */
    children?: React.LabelHTMLAttributes<HTMLLabelElement>['children'];
    /**
     * Override or extend the styles applied to the component.
     */
    classes?: Partial<FormLabelClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning', FormLabelPropsColorOverrides>;
    /**
     * If `true`, the label should be displayed in a disabled state.
     */
    disabled?: boolean;
    /**
     * If `true`, the label is displayed in an error state.
     */
    error?: boolean;
    /**
     * If `true`, the label should use filled classes key.
     */
    filled?: boolean;
    /**
     * If `true`, the input of this label is focused (used by `FormGroup` components).
     */
    focused?: boolean;
    /**
     * If `true`, the label will indicate that the `input` is required.
     */
    required?: boolean;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    component?: React.ElementType;
};
declare const FormLabel: (props: FormLabelTextProps) => React.JSX.Element;

type SlideProps = PropsWithChildren & {
    key?: string;
    /**
   * Perform the enter transition when it first mounts if `in` is also `true`.
   * Set this to `false` to disable this behavior.
   * @default true
   */
    appear?: boolean;
    /**
     * A single child content element.
     */
    children: React.ReactElement<any, any>;
    /**
     * An HTML element, or a function that returns one.
     * It's used to set the container the Slide is transitioning from.
     */
    container?: null | Element | ((element: Element) => Element);
    /**
     * Direction the child node will enter from.
     * @default 'down'
     */
    direction?: 'left' | 'right' | 'up' | 'down';
    /**
     * The transition timing function.
     * You may specify a single easing or a object containing enter and exit values.
     * @default {
     *   enter: theme.transitions.easing.easeOut,
     *   exit: theme.transitions.easing.sharp,
     * }
     */
    easing?: TransitionProps['easing'];
    /**
     * If `true`, the component will transition in.
     */
    in?: TransitionProps['in'];
    ref?: React.Ref<unknown>;
    /**
     * The duration for the transition, in milliseconds.
     * You may specify a single timeout for all transitions, or individually with an object.
     * @default {
     *   enter: theme.transitions.duration.enteringScreen,
     *   exit: theme.transitions.duration.leavingScreen,
     * }
     */
    timeout?: TransitionProps['timeout'];
};
declare const Slide: (props: SlideProps) => React.JSX.Element;

type CircularProgressProps = PropsWithChildren & {
    key?: string;
    /**
    * Override or extend the styles applied to the component.
    */
    classes?: Partial<CircularProgressClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning' | 'inherit', CircularProgressPropsColorOverrides>;
    /**
     * If `true`, the shrink animation is disabled.
     * This only works if variant is `indeterminate`.
     * @default false
     */
    disableShrink?: boolean;
    /**
     * The size of the component.
     * If using a number, the pixel unit is assumed.
     * If using a string, you need to provide the CSS unit, for example '3rem'.
     * @default 40
     */
    size?: number | string;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The thickness of the circle.
     * @default 3.6
     */
    thickness?: number;
    /**
     * The value of the progress indicator for the determinate variant.
     * Value between 0 and 100.
     * @default 0
     */
    value?: number;
    /**
     * The variant to use.
     * Use indeterminate when there is no progress value.
     * @default 'indeterminate'
     */
    variant?: 'determinate' | 'indeterminate';
};
declare const CircularProgress: (props: CircularProgressProps) => React.JSX.Element;

type LinearProgressProps = PropsWithChildren & {
    key?: string;
    /**
   * Override or extend the styles applied to the component.
   */
    classes?: Partial<LinearProgressClasses>;
    /**
     * The color of the component.
     * It supports both default and custom theme colors, which can be added as shown in the
     * [palette customization guide](https://mui.com/material-ui/customization/palette/#custom-colors).
     * @default 'primary'
     */
    color?: OverridableStringUnion<'primary' | 'secondary' | 'error' | 'info' | 'success' | 'warning' | 'inherit', LinearProgressPropsColorOverrides>;
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps<Theme>;
    /**
     * The value of the progress indicator for the determinate and buffer variants.
     * Value between 0 and 100.
     */
    value?: number;
    /**
     * The value for the buffer variant.
     * Value between 0 and 100.
     */
    valueBuffer?: number;
    /**
     * The variant to use.
     * Use indeterminate or query when there is no progress value.
     * @default 'indeterminate'
     */
    variant?: 'determinate' | 'indeterminate' | 'buffer' | 'query';
};
declare const LinearProgress: (props: LinearProgressProps) => React.JSX.Element;

type StackProps = PropsWithChildren & {
    key?: string;
    /**
    * The content of the component.
    */
    children?: React.ReactNode;
    /**
     * Defines the `flex-direction` style property.
     * It is applied for all screen sizes.
     * @default 'column'
     */
    direction?: ResponsiveStyleValue<'row' | 'row-reverse' | 'column' | 'column-reverse'>;
    /**
     * Defines the space between immediate children.
     * @default 0
     */
    spacing?: ResponsiveStyleValue<number | string>;
    /**
     * Add an element between each child.
     */
    divider?: React.ReactNode;
    /**
     * If `true`, the CSS flexbox `gap` is used instead of applying `margin` to children.
     *
     * While CSS `gap` removes the [known limitations](https://mui.com/joy-ui/react-stack/#limitations),
     * it is not fully supported in some browsers. We recommend checking https://caniuse.com/?search=flex%20gap before using this flag.
     *
     * To enable this flag globally, follow the [theme's default props](https://mui.com/material-ui/customization/theme-components/#default-props) configuration.
     * @default false
     */
    useFlexGap?: boolean;
    /**
     * The system prop, which allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps$1<Theme$1>;
};
declare const Stack: (props: StackProps) => React.JSX.Element;

type IconNames = keyof typeof Icons;
type IconProps = {
    iconName: IconNames;
};
declare const Icon: FC<IconProps>;

export { Accordion, AccordionDetails, type AccordionSlots, AccordionSummary, Alert, AlertTitle, AppBar, Avatar, AvatarGroup, Backdrop, Badge, Box, Button, ButtonGroup, Card, CardActions, CardContent, Checkbox, Chip, CircularProgress, Dialog, DialogActions, DialogContent, DialogContentText, DialogTitle, Divider, Drawer, FormControl, FormControlLabel, FormGroup, FormHelperText, FormLabel, Grid, Icon, LinearProgress, Link, List, ListItem, ListItemAvatar, ListItemButton, ListItemIcon, ListItemSecondaryAction, ListItemText, ListSubheader, Menu, MenuItem, MenuList, Paper, Slide, Stack, Step, StepButton, StepContent, StepLabel, Stepper, SwipeableDrawer, Tab, Table, TableBody, TableCell, TableContainer, TableFooter, TableHead, TablePagination, TableRow, TableSortLabel, Tabs, Toolbar, Tooltip, Typography };
